## What is it?
This package is a collection of useful tools for analytics, statistics and data science.

## How to contact the autor?
You can easily mail me: timofei.ryko@gmail.com (for collaboration, offers or just for fun). Also feel fre to contact me in telegram: @timofeiryko
